# Generated by roxygen2: do not edit by hand

export(BestC)
export(CKNNRLD)
export(CKNNRLD.tune)
export(KNNRLD)
export(KNNRLD.tune)
importFrom(Directional,makefolds)
importFrom(Rfast,colmeans)
importFrom(Rfast,dista)
importFrom(graphics,abline)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(stats,kmeans)
